#!/bin/bash

# This is a shell script which fetches a satellite cloud image for xplanet
# from the xplanet homepage. 
#
# The script is based on Hari Nair's <hari@alumni.caltech.edu> script on
# http://xplanet.sourceforge.net/updateclouds. 
# See http://xplanet.sourceforge.net/ for details. 
#
# It assumes that a .xplanet directory in the user's home is present!

if ! [ -d $HOME/.xplanet ] ; then
	echo Please create a directory for me first, by entering \'mkdir \~/.xplanet\'
	exit 0
fi

# don't show any images now, just generate them
unset DISPLAY

# get the cloud image. 
cd /tmp
rm -f clouds_1600.jpg
wget --proxy=off --tries=5 --continue http://xplanet.sourceforge.net/clouds_1600.jpg 

# render day image with clouds and put it in ~/.xplanet
/usr/X11R6/bin/xplanet -image earth.jpg \
    -cloud_image clouds_1600.jpg -cloud_thresh 0 -shade 100 \
    -output ${HOME}/.xplanet/day_clouds.png -geometry 1600x1024

# render night image
/usr/X11R6/bin/xplanet -image night.jpg \
    -cloud_image clouds_1600.jpg -cloud_thresh 0 -cloud_shade 30 \
    -output ${HOME}/.xplanet/night_clouds.png -geometry 1600x1024

